@@ -4,14 +4,16 @@ Modules for accessing data and attributes in the central database.
 
 import os
 import warnings
+
 from abc import ABCMeta, abstractmethod
 from typing import Dict, List, Optional, Tuple, Union
 
 import h5py
 import numpy as np
+
 from typeguard import typechecked
 
-from pynpoint.util.types import NonStaticAttribute, StaticAttribute
+from pynpoint.util.type_aliases import NonStaticAttribute, StaticAttribute
 
 
 class DataStorage:
@@ -226,7 +228,7 @@ class ConfigPort(Port):
             None
         """
 
-        super(ConfigPort, self).__init__(tag, data_storage_in)
+        super().__init__(tag, data_storage_in)
 
         if tag != 'config':
             raise ValueError('The tag name of the central configuration should be \'config\'.')
@@ -373,7 +375,7 @@ class InputPort(Port):
             None
         """
 
-        super(InputPort, self).__init__(tag, data_storage_in)
+        super().__init__(tag, data_storage_in)
 
         if tag == 'config':
             raise ValueError('The tag name \'config\' is reserved for the central configuration '
@@ -675,7 +677,7 @@ class OutputPort(Port):
             None
         """
 
-        super(OutputPort, self).__init__(tag, data_storage_in)
+        super().__init__(tag, data_storage_in)
 
         self.m_activate = activate_init
 
@@ -858,15 +860,15 @@ class OutputPort(Port):
                     data_dim: Optional[int] = None,
                     force: bool = False) -> None:
         """
-        Internal function for appending data to a dataset or appending non-static attribute
-        information. See :func:`~pynpoint.core.dataio.OutputPort.append` for more information.
+        Internal function for appending data to a dataset or appending non-static attributes.
+        See :func:`~pynpoint.core.dataio.OutputPort.append` for more information.
 
         Parameters
         ----------
         tag : str
-            Database tag of the data that will be modified.
+            Database tag where the data will be stored.
         data : np.ndarray
-            The data that will be stored and replace any old data.
+            The data that will be appended.
         data_dim : int
             Number of dimension of the data.
         force : bool
@@ -900,8 +902,10 @@ class OutputPort(Port):
 
             if data_dim == 2:
                 data = data[np.newaxis, :]
+
             elif data_dim == 3:
                 data = data[np.newaxis, :, :]
+
             elif data_dim == 4:
                 data = data[:, np.newaxis, :, :]
 
@@ -1069,31 +1073,30 @@ class OutputPort(Port):
                data_dim: Optional[int] = None,
                force: bool = False) -> None:
         """
-        Appends data to an existing dataset with the tag of the Port along the first
-        dimension. If no data exists with the tag of the Port a new data set is created.
-        For more information about how the dimensions are organized see documentation of
-        the function :func:`~pynpoint.core.dataio.OutputPort.set_all`. Note it is not possible to
-        append data with a different shape or data type to the existing dataset.
+        Appends data to an existing dataset along the first dimension. If no data exists for the
+        :class:`~pynpoint.core.dataio.OutputPort`, then a new data set is created. For more
+        information about how the dimensions are organized, see the documentation of
+        :func:`~pynpoint.core.dataio.OutputPort.set_all`. Note it is not possible to append data
+        with a different shape or data type to an existing dataset.
 
-        **Example:** An internal data set is 3D (storing a stack of 2D images) with shape
-        (233, 300, 300) which mean it contains 233 images with a resolution of 300 x 300 pixel.
-        Thus it is only possible to extend along the first dimension by appending new images with
-        a size of (300, 300) or by appending a stack of images (:, 300, 300). Everything else will
-        raise exceptions.
+        **Example:** An internal data set is 3D (storing a stack of 2D images) with shape of
+        ``(233, 300, 300)``, that is, it contains 233 images with a resolution of 300 by 300
+        pixels. Thus it is only possible to extend along the first dimension by appending new
+        images with a shape of ``(300, 300)`` or by appending a stack of images with a shape of
+        ``(:, 300, 300)``.
 
-        It is possible to force the function to overwrite the existing data set if and only if the
-        shape or type of the input data does not match the existing data. **Warning**: This can
-        delete the existing data.
+        It is possible to force the function to overwrite existing data set if the shape or type of
+        the input data do not match the existing data.
 
         Parameters
         ----------
         data : np.ndarray
-            The data which will be appended.
+            The data that will be appended.
         data_dim : int
             Number of data dimensions used if a new data set is created. The dimension of the
-            *data* is used if set to None.
+            ``data`` is used if set to None.
         force : bool
-            The existing data will be overwritten if shape or type does not match if set to True.
+            The existing data will be overwritten if the shape or type does not match.
 
         Returns
         -------
@@ -1174,7 +1177,8 @@ class OutputPort(Port):
         if self._check_status_and_activate():
 
             if self._m_tag not in self._m_data_storage.m_data_bank:
-                warnings.warn('Can not store attribute if data tag does not exist.')
+                warnings.warn(f'Can not store the attribute \'{name}\' because the dataset '
+                              f'\'{self._m_tag}\' does not exist.')
 
             else:
                 if static:
