@@ -47,7 +47,7 @@ class ContrastCurveModule(ProcessingModule):
                  cent_size: Optional[float] = None,
                  edge_size: Optional[float] = None,
                  extra_rot: float = 0.,
-                 residuals: str = 'median',
+                 residuals: str = 'mean',
                  snr_inject: float = 100.,
                  **kwargs: float) -> None:
         """
@@ -293,6 +293,7 @@ class ContrastCurveModule(ProcessingModule):
         result = result[indices]
 
         result = result.reshape((pos_r.size, pos_t.size, 4))
+        result[np.isinf(result)] = np.nan
 
         mag_mean = np.nanmean(result, axis=1)[:, 2]
         mag_var = np.nanvar(result, axis=1)[:, 2]
