@@ -19,9 +19,8 @@ import numpy as np
 import pywt
 
 from numba import jit
-from photutils import aperture_photometry
-from photutils.aperture import Aperture
-from scipy.ndimage.filters import gaussian_filter
+from photutils.aperture import Aperture, aperture_photometry
+from scipy.ndimage import gaussian_filter
 from scipy.optimize import curve_fit
 from skimage.registration import phase_cross_correlation
 from skimage.transform import rescale
@@ -98,6 +97,7 @@ def align_image(image_in: np.ndarray,
         if subframe is None:
             tmp_offset, _, _ = phase_cross_correlation(ref_images[i, :, :],
                                                        image_in,
+                                                       normalization=None,
                                                        upsample_factor=accuracy)
 
         else:
@@ -106,6 +106,7 @@ def align_image(image_in: np.ndarray,
 
             tmp_offset, _, _ = phase_cross_correlation(sub_ref,
                                                        sub_in,
+                                                       normalization=None,
                                                        upsample_factor=accuracy)
         offset += tmp_offset
 
@@ -120,7 +121,7 @@ def align_image(image_in: np.ndarray,
                             (resize, resize),
                             order=5,
                             mode='reflect',
-                            multichannel=False,
+                            channel_axis=None,
                             anti_aliasing=True)
 
         sum_after = np.sum(tmp_image)
@@ -321,7 +322,7 @@ def fit_2d_function(image: np.ndarray,
             popt = np.zeros(8)
             perr = np.zeros(8)
 
-        print(f'Fit could not converge on image number {im_index}. [WARNING]')
+        warnings.warn(f'Fit could not converge on image number {im_index}.')
 
     if model == 'gaussian':
 
@@ -382,7 +383,7 @@ def crop_around_star(image: np.ndarray,
                       f'image instead.')
 
         if index_out_port is not None:
-            index_out_port.append(im_index, data_dim=1)
+            index_out_port.append([im_index], data_dim=1)
 
         starpos = center_pixel(image)
         im_crop = crop_image(image, tuple(starpos), im_size)
@@ -411,7 +412,7 @@ def crop_rotating_star(image: np.ndarray,
 @typechecked
 def photometry(image: np.ndarray,
                im_index: int,
-               aperture: Union[Aperture, List[Aperture]]) -> np.float64:
+               aperture: Union[Aperture, List[Aperture]]) -> np.ndarray:
     # https://photutils.readthedocs.io/en/stable/overview.html
     # In Photutils, pixel coordinates are zero-indexed, meaning that (x, y) = (0, 0)
     # corresponds to the center of the lowest, leftmost array element. This means that
@@ -586,7 +587,7 @@ def time_filter(timeline: np.ndarray,
 
 
 # This function cannot by @typechecked because of a compatibility issue with numba
-@jit(cache=True)
+@jit(cache=True, nopython=True)
 def calc_fast_convolution(F_roof_tmp: np.complex128,
                           W: np.ndarray,
                           tmp_s: tuple,
@@ -756,7 +757,7 @@ def replace_pixels(image: np.ndarray,
 
 
 # This function cannot by @typechecked because of a compatibility issue with numba
-@jit(cache=True)
+@jit(cache=True, nopython=True)
 def sigma_filter(dev_image: np.ndarray,
                  var_image: np.ndarray,
                  mean_image: np.ndarray,
