@@ -3,6 +3,7 @@ Abstract interfaces for multiprocessing applications with the poison pill patter
 """
 
 import multiprocessing
+from sys import platform
 
 from typing import Callable, Optional, Union
 from abc import ABCMeta, abstractmethod
@@ -14,10 +15,11 @@ from typeguard import typechecked
 from pynpoint.core.dataio import InputPort, OutputPort
 
 
-# On macOS, the spawn start method is the default since Python 3.8. The fork start method should
-# be considered unsafe as it can lead to crashes of the subprocess.
-# TODO Not using the fork method results in an error.
-multiprocessing.set_start_method('fork')
+# On macOS, the spawn start method is the default since Python 3.8.
+# The fork start method should be considered unsafe as it can lead
+# to crashes of the subprocess according to the documentation.
+if platform in ['darwin', 'linux']:
+    multiprocessing.set_start_method('fork')
 
 
 class TaskInput:
@@ -27,7 +29,7 @@ class TaskInput:
 
     @typechecked
     def __init__(self,
-                 input_data: Union[np.ndarray, np.int64, tuple],
+                 input_data: Union[np.ndarray, np.integer, tuple],
                  job_parameter: tuple) -> None:
         """
         Parameters
